@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Error::TypeTiny::WrongNumberOfParameters::AUTHORITY = 'cpan:TOBYINK';
-	$Error::TypeTiny::WrongNumberOfParameters::VERSION   = '1.010001';
+	$Error::TypeTiny::WrongNumberOfParameters::VERSION   = '1.016008';
 }
 
 $Error::TypeTiny::WrongNumberOfParameters::VERSION =~ tr/_//d;
@@ -14,26 +14,23 @@ $Error::TypeTiny::WrongNumberOfParameters::VERSION =~ tr/_//d;
 require Error::TypeTiny;
 our @ISA = 'Error::TypeTiny';
 
-sub minimum    { $_[0]{minimum} };
-sub maximum    { $_[0]{maximum} };
-sub got        { $_[0]{got} };
+sub minimum { $_[0]{minimum} }
+sub maximum { $_[0]{maximum} }
+sub got     { $_[0]{got} }
 
-sub has_minimum { exists $_[0]{minimum} };
-sub has_maximum { exists $_[0]{maximum} };
+sub has_minimum { exists $_[0]{minimum} }
+sub has_maximum { exists $_[0]{maximum} }
 
-sub _build_message
-{
+sub _build_message {
 	my $e = shift;
-	if ($e->has_minimum and $e->has_maximum and $e->minimum == $e->maximum)
-	{
+	if ( $e->has_minimum and $e->has_maximum and $e->minimum == $e->maximum ) {
 		return sprintf(
 			"Wrong number of parameters; got %d; expected %d",
 			$e->got,
 			$e->minimum,
 		);
 	}
-	elsif ($e->has_minimum and $e->has_maximum and $e->minimum < $e->maximum)
-	{
+	elsif ( $e->has_minimum and $e->has_maximum and $e->minimum < $e->maximum ) {
 		return sprintf(
 			"Wrong number of parameters; got %d; expected %d to %d",
 			$e->got,
@@ -41,22 +38,20 @@ sub _build_message
 			$e->maximum,
 		);
 	}
-	elsif ($e->has_minimum)
-	{
+	elsif ( $e->has_minimum ) {
 		return sprintf(
 			"Wrong number of parameters; got %d; expected at least %d",
 			$e->got,
 			$e->minimum,
 		);
 	}
-	else
-	{
+	else {
 		return sprintf(
 			"Wrong number of parameters; got %d",
 			$e->got,
 		);
 	}
-}
+} #/ sub _build_message
 
 1;
 
@@ -114,7 +109,7 @@ Predicate methods.
 =head1 BUGS
 
 Please report any bugs to
-L<http://rt.cpan.org/Dist/Display.html?Queue=Type-Tiny>.
+L<https://github.com/tobyink/p5-type-tiny/issues>.
 
 =head1 SEE ALSO
 
@@ -126,7 +121,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2020 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -136,4 +131,3 @@ the same terms as the Perl 5 programming language system itself.
 THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-
